/**
 * It's important this file isn't referenced ahead of a `configure` call, otherwise these values may remain fixed at
 * their defaults. Consumers must use the `/config` subpath to help avoid this. Files with references to tags should be
 * lazily loaded. There is an alternative `getTags` utility at the end which could offer another approach, but direct
 * tag exports and inline template references feel cleaner than having to convert all component `template` and `styles`
 * exports to functions to call `getTags` on execution.
 */
/**
 * @internal
 */
export declare const templateOptions: import("../config/templates").TemplateOptions;
/**
 * @internal
 */
export declare const iconTag: string;
/**
 * @internal
 */
export declare const buttonTag: string;
/**
 * @internal
 */
export declare const connectionIndicatorTag: string;
/**
 * @internal
 */
export declare const selectTag: string;
/**
 * @internal
 */
export declare const optionTag: string;
/**
 * @internal
 */
export declare const flyoutTag: string;
/**
 * @internal
 */
export declare const providerTag: string;
/**
 * @param tagName - The tag name.
 * @param dsPrefix - The design system prefix.
 *
 * @returns The tag for the given tag name and design system prefix.
 *
 * @remarks
 *
 * This function is useful for getting tags when the design system prefix is not known at compile time.
 *
 * @internal
 */
export declare const getTagHelper: (dsPrefix: any, tagName: any) => string;
//# sourceMappingURL=tags.d.ts.map